import { toString } from "uint8arrays";
import { Mode } from "@canvas-js/okra";
import { Tree as MemoryTree } from "@canvas-js/okra-memory";
import { ModelDB, ModelDBProxy } from "@canvas-js/modeldb-durable-objects";
import { AbstractGossipLog } from "../AbstractGossipLog.js";
import { MerkleIndex } from "../MerkleIndex.js";
export class GossipLog extends AbstractGossipLog {
    static async open({ db, worker, useTestProxy, clear, ...init }) {
        let mdb;
        if (useTestProxy && worker) {
            mdb = new ModelDBProxy(worker, { ...init.schema, ...AbstractGossipLog.schema });
            await mdb.initialize();
        }
        else if (!useTestProxy && db) {
            mdb = new ModelDB({ db, models: { ...init.schema, ...AbstractGossipLog.schema } });
        }
        else {
            throw new Error("must provide db or worker && useTestProxy");
        }
        if (clear) {
            for (const table of Object.keys({ ...init.schema, ...AbstractGossipLog.schema })) {
                await mdb.clear(table);
            }
        }
        const messageCount = await mdb.count("$messages");
        const merkleIndex = new MerkleIndex(mdb);
        const start = performance.now();
        const tree = await MemoryTree.fromEntries({ mode: Mode.Index }, merkleIndex.entries());
        const root = await tree.read((txn) => txn.getRoot());
        const delta = performance.now() - start;
        const gossipLog = new GossipLog(mdb, tree, init);
        gossipLog.log(`build in-memory merkle tree (root %d:%s, %d entries, %dms)`, root.level, toString(root.hash, "hex"), messageCount, Math.round(delta));
        return gossipLog;
    }
    constructor(db, tree, init) {
        super(init);
        Object.defineProperty(this, "db", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: db
        });
        Object.defineProperty(this, "tree", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: tree
        });
    }
}
