import { Startable, PubSub, Libp2pEvents, TypedEventTarget } from "@libp2p/interface";
import { ConnectionManager, Registrar } from "@libp2p/interface-internal";
import { GossipSub, GossipsubEvents } from "@chainsafe/libp2p-gossipsub";
import { AbstractGossipLog } from "../AbstractGossipLog.js";
export interface GossipLogServiceComponents {
    pubsub: PubSub<GossipsubEvents>;
    events: TypedEventTarget<Libp2pEvents>;
    registrar: Registrar;
    connectionManager: ConnectionManager;
}
export interface GossipLogServiceInit<Payload> {
    gossipLog: AbstractGossipLog<Payload>;
}
export declare class GossipLogService<Payload = unknown> implements Startable {
    #private;
    private readonly components;
    private static extractGossipSub;
    readonly pubsub: GossipSub;
    readonly messageLog: AbstractGossipLog<Payload>;
    private readonly log;
    private readonly syncProtocol;
    private readonly pushProtocol;
    private readonly syncQueue;
    private readonly syncQueuePeers;
    private readonly pushTopology;
    private readonly eventSources;
    constructor(components: GossipLogServiceComponents, { gossipLog }: GossipLogServiceInit<Payload>);
    beforeStart(): void;
    start(): Promise<void>;
    afterStart(): void;
    beforeStop(): void;
    stop(): Promise<void>;
    private newStream;
    private handleConnectionOpen;
    private handleConnectionClose;
    private handleGossipsubGraft;
    private handleGossipsubPrune;
    private handleMessage;
    private handleSync;
    private handleGossipsubMessage;
    private getEventSink;
    private handleInsertEvent;
    private handleUpdateEvent;
    private handlePushStream;
    private handleSyncStream;
    private scheduleSync;
    private sync;
}
export declare const gossipLogService: <Payload>(init: GossipLogServiceInit<Payload>) => (components: GossipLogServiceComponents) => GossipLogService<Payload>;
