import { type Codec, type DecodeOptions } from 'protons-runtime';
import type { Uint8ArrayList } from 'uint8arraylist';
export interface Node {
    level: number;
    key?: Uint8Array;
    hash: Uint8Array;
}
export declare namespace Node {
    const codec: () => Codec<Node>;
    const encode: (obj: Partial<Node>) => Uint8Array;
    const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<Node>) => Node;
}
export interface Request {
    getRoot?: Request.GetRootRequest;
    getNode?: Request.GetNodeRequest;
    getChildren?: Request.GetChildrenRequest;
    getValues?: Request.GetValuesRequest;
}
export declare namespace Request {
    interface GetRootRequest {
    }
    namespace GetRootRequest {
        const codec: () => Codec<GetRootRequest>;
        const encode: (obj: Partial<GetRootRequest>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetRootRequest>) => GetRootRequest;
    }
    interface GetNodeRequest {
        level: number;
        key?: Uint8Array;
    }
    namespace GetNodeRequest {
        const codec: () => Codec<GetNodeRequest>;
        const encode: (obj: Partial<GetNodeRequest>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetNodeRequest>) => GetNodeRequest;
    }
    interface GetChildrenRequest {
        level: number;
        key?: Uint8Array;
    }
    namespace GetChildrenRequest {
        const codec: () => Codec<GetChildrenRequest>;
        const encode: (obj: Partial<GetChildrenRequest>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetChildrenRequest>) => GetChildrenRequest;
    }
    interface GetValuesRequest {
        keys: Uint8Array[];
    }
    namespace GetValuesRequest {
        const codec: () => Codec<GetValuesRequest>;
        const encode: (obj: Partial<GetValuesRequest>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetValuesRequest>) => GetValuesRequest;
    }
    const codec: () => Codec<Request>;
    const encode: (obj: Partial<Request>) => Uint8Array;
    const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<Request>) => Request;
}
export interface Response {
    getRoot?: Response.GetRootResponse;
    getNode?: Response.GetNodeResponse;
    getChildren?: Response.GetChildrenResponse;
    getValues?: Response.GetValuesResponse;
    abort?: Response.Abort;
}
export declare namespace Response {
    interface GetRootResponse {
        root?: Node;
    }
    namespace GetRootResponse {
        const codec: () => Codec<GetRootResponse>;
        const encode: (obj: Partial<GetRootResponse>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetRootResponse>) => GetRootResponse;
    }
    interface GetNodeResponse {
        node?: Node;
    }
    namespace GetNodeResponse {
        const codec: () => Codec<GetNodeResponse>;
        const encode: (obj: Partial<GetNodeResponse>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetNodeResponse>) => GetNodeResponse;
    }
    interface GetChildrenResponse {
        children: Node[];
    }
    namespace GetChildrenResponse {
        const codec: () => Codec<GetChildrenResponse>;
        const encode: (obj: Partial<GetChildrenResponse>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetChildrenResponse>) => GetChildrenResponse;
    }
    interface GetValuesResponse {
        values: Uint8Array[];
    }
    namespace GetValuesResponse {
        const codec: () => Codec<GetValuesResponse>;
        const encode: (obj: Partial<GetValuesResponse>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<GetValuesResponse>) => GetValuesResponse;
    }
    interface Abort {
        cooldown: number;
    }
    namespace Abort {
        const codec: () => Codec<Abort>;
        const encode: (obj: Partial<Abort>) => Uint8Array;
        const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<Abort>) => Abort;
    }
    const codec: () => Codec<Response>;
    const encode: (obj: Partial<Response>) => Uint8Array;
    const decode: (buf: Uint8Array | Uint8ArrayList, opts?: DecodeOptions<Response>) => Response;
}
